@@ -64,7 +64,7 @@ qw/
 /
 );
 
-our $VERSION = '1.1.10'; $VERSION=~s/\-.*$//;
+our $VERSION = '1.1.11'; $VERSION=~s/\-.*$//;
 
 sub new {
   my $class = shift;
@@ -117,25 +117,35 @@ sub new {
 
 sub _create_methods {
   my ($self) = @_;
-
+  
   my $class = ref($self) || $self;
-
+  
   if ( $self->get_api_methods ) {
     no strict 'refs';
     no warnings 'redefine';
 
+    my $stash = \%{'Amazon::EC2::'};
+
     foreach my $api ( @{ $self->get_api_methods } ) {
+
       my $method = lcfirst $api;
 
       $method =~ s/([a-z])([A-Z])/$1_$2/g;
       $method = lc $method;
 
-      # snake case rules the day
-      *{ "$class::" . $method } = sub { shift->invoke_api( "$api", @_ ) };
+      my $snake_case_method = $class . '::' . $method;
+      my $CamelCaseMethod= $class . '::' . $api;
 
-      # but some prefer camels
-      *{ "$class::" . $api } = sub { shift->$method(@_) }; # pass on to the snake
+      # snake case rules the day
+      *{ $snake_case_method } = sub { my $self = shift; $self->invoke_api( "$api", @_ ) }
+        if ! $stash->{$method};
+
+      # ...but some prefer camels
+      *{ $CamelCaseMethod } = sub { my $self = shift; $self->$method(@_) }
+        if ! $stash->{$api};
+      
     } ## end foreach my $api ( @{ $self->...})
+
   } ## end if ( $self->get_api_methods)
 
   return $self;
@@ -243,15 +253,13 @@ sub invoke_api {
   $self->set_error(undef);
 
   my $content;
-
-  $content_type = $self->get_content_type
-    if !$parameters && !$content_type;
-
+  my $default_content_type = $self->get_content_type;
+  
   # guessing game...if you do not provide a content type
   if ( !$content_type ) {
     
     if ( ref($parameters) && reftype($parameters) eq 'HASH' ) {
-      $content_type = $self->get_content_type;
+      $content_type = $default_content_type;
       $content      = encode_json($parameters);
     }
     elsif ( ref($parameters) && reftype($parameters) eq 'ARRAY' ) {
